pub struct AbsUtf8PathError { /* private fields */ }Expand description
An error indicating that a path was not a well-formed absolute path.
Returned by AbsUtf8PathBuf::new.
Implementations
Sourceimpl AbsUtf8PathError
impl AbsUtf8PathError
Sourcepub fn into_path(self) -> Utf8PathBuf
pub fn into_path(self) -> Utf8PathBuf
Consumes the error, returning the path that was rejected.
Sourcepub fn kind(&self) -> AbsUtf8PathErrorKind
pub fn kind(&self) -> AbsUtf8PathErrorKind
Returns the reason the path was rejected.